/* NitroShare - A simple network file sharing tool.
   Copyright (C) 2012 Nathan Osman

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>. */

#include <QHostAddress>
#include <QNetworkInterface>

#include <file/CFileReceiver.h>
#include <file/CFileServer.h>
#include <util/network.h>
#include <util/settings.h>

CFileServer::CFileServer()
{
    //...
}

void CFileServer::Init()
{
    // Stop listening if we already are listen on the new port
    close();

    // Attempt to find the IPv4 address for the current network interface
    QHostAddress address;
    if(!Network::FindIPv4Address(Network::GetCurrentInterface(), Network::IPAddress, &address))
    {
        if(Settings::Notify("Error"))
            emit Message(tr("Unable to find an IPv4 address on the current network interface."),
                         QSystemTrayIcon::Critical);

        return;
    }

    if(!listen(address, Settings::Get("Network/TransmissionPort").toUInt()) && Settings::Notify("Error"))
        emit Message(tr("Unable to listen on TCP port %1.")
                         .arg(Settings::Get("Network/TransmissionPort").toUInt()),
                     QSystemTrayIcon::Critical);
}

void CFileServer::incomingConnection(int handle)
{
    connect(new CFileReceiver(this, handle),
            SIGNAL(Message(QString,QSystemTrayIcon::MessageIcon)),
            SIGNAL(Message(QString,QSystemTrayIcon::MessageIcon)));
}
